==> pycountrycode-1.1.1.tar.gz: pycountrycode-1.1.1/README.md <==
**Welcome to PyCountryCode's documentation!** 
=============================================

**What it is?***
I have always loved knowing stuff. I love knowledge, it is my first love before anything else. In every kind of setup I finf myself in I am always participating because I almost always have an idea about most things. This love of knowledge also made it easy for me to know more country telephone codes. 

However, the truth is I couldn't cram them all the country codes and retrieve them from my mind everytime it became necessary. I knew by heart those of the most popular countries that includes Russia (+7), UK (+44), USA (+1), Australia (+61) and of course Zimbabwe amongst many others.

**Why?**
Someone wanted to know what code +52 was for which country, I didn't know, I was embarrassed at myself. I challenged myself by writing this package so I and anyone else can use to get the country calling code of any country and also to get a country after passing in a calling code you know but are not sure about the country of origin.

**Inspiration**
I wanted to write something that others could find useful.


**Installation**

1. ***pip install pycountrycode***

**Importing the 'code' function**

2. ***from pycountrycode.pycountrycode import code***

***code('Zimbabwe')***
***'+263'***
***code('New Zealand')***
***'+64'
***code('Peru')***
***'+51'***
***code('Madagascar')***
***'+261'***
***code('Russia')
***'+7'***
***code('Australia')***
***'+61'***
***code('Israel')***
***'+972'***
>>>

**importing the phoneCode function.**

3. ***from pycountrycode.countrycode import phoneCode***

- ***phoneCode('+52')***
- 'Mexico'
- ***phoneCode('+56')***
- 'Easter Island'
- ***phoneCode('+1')***
- 'United States of America'
- ***phoneCode('+7')***
- 'Russia'
- ***phoneCode('+44')***
- 'Britain'
- ***phoneCode('+86')***
- 'China'

==> pycountrycode-1.1.2.tar.gz: pycountrycode-1.1.2/README.md <==
**Welcome to PyCountryCode's documentation!** 
=============================================

**What it is?**
I have always loved knowing stuff. I love knowledge, it is my first love before anything else. In every kind of setup I finf myself in I am always participating because I almost always have an idea about most things. This love of knowledge also made it easy for me to know more country telephone codes. 

However, the truth is I couldn't cram them all the country codes and retrieve them from my mind everytime it became necessary. I knew by heart those of the most popular countries that includes Russia (+7), UK (+44), USA (+1), Australia (+61) and of course Zimbabwe amongst many others.

**Why?**
Someone wanted to know what code +52 was for which country, I didn't know, I was embarrassed at myself. I challenged myself by writing this package so I and anyone else can use to get the country calling code of any country and also to get a country after passing in a calling code you know but are not sure about the country of origin.

**Inspiration**
I wanted to write something that others could find useful.


**Installation**
***pip install pycountrycode***

**Importing the 'code' function**
***from pycountrycode.pycountrycode import code***

***code('Zimbabwe')***
- '+263'
***code('New Zealand')***
- '+64'
***code('Peru')***
- '+51'
***code('Madagascar')***
- '+261'
***code('Russia')
- '+7'
***code('Australia')***
- '+61'
***code('Israel')***
- '+972'

**importing the 'phoneCode' function.**
***from pycountrycode.countrycode import phoneCode***

- ***phoneCode('+52')***
- 'Mexico'
- ***phoneCode('+56')***
- 'Easter Island'
- ***phoneCode('+1')***
- 'United States of America'
- ***phoneCode('+7')***
- 'Russia'
- ***phoneCode('+44')***
- 'Britain'
- ***phoneCode('+86')***
- 'China'
